use crate::models::users::UserID;
use crate::schema::*;
use diesel::prelude::*;

#[derive(Debug, Clone, Copy, serde::Serialize, serde::Deserialize, PartialEq, Eq)]
pub struct AccountID(pub i32);

#[derive(Queryable, Debug, Clone, serde::Serialize)]
pub struct Account {
    id: i32,
    pub name: String,
    user_id: i32,
    pub time_create: i64,
    pub time_update: i64,
    pub default_account: bool,
}

impl Account {
    pub fn id(&self) -> AccountID {
        AccountID(self.id)
    }

    pub fn user_id(&self) -> UserID {
        UserID(self.user_id)
    }
}

#[derive(Insertable)]
#[diesel(table_name = accounts)]
pub struct NewAccount<'a> {
    pub name: &'a str,
    pub user_id: i32,
    pub time_create: i64,
    pub time_update: i64,
}
